@@ -168,7 +168,13 @@ __END__
 
 =head1 NAME
 
-HTTP::Session2::ClientStore - (Deprecated)Client store
+HTTP::Session2::ClientStore - (Deprecated) Client store
+
+=head1 DEPRECATION NOTICE
+
+This module is B<DEPRECATED> and no longer maintained.
+Please do not use this module for new projects.
+See L<HTTP::Session2> for details.
 
 =head1 DESCRIPTION
 
